ConstraintsDto<Self extends ConstraintsDto<Self, Value>, Value extends Constraints> class abstract

Inheritance
Implementers

Constructors

ConstraintsDto()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
no setterinherited

Methods

getDiff(EqualityMixin other) Map<String, String>
inherited
merge(covariant dynamic other) → dynamic
Merges this object with other, returning a new object of type T.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(MixData mix) → Value
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited