DecorationDto<Value extends Decoration> class abstract

A Data transfer object that represents a Decoration value.

This DTO is used to resolve a Decoration value from a MixData instance.

This class needs to have the different properties that are not found in the Modifiers class. In order to support merging of Decoration values, and reusable of common properties.

Inheritance
Implementers
Annotations

Constructors

DecorationDto({required ColorDto? color, required GradientDto<Gradient>? gradient, required List<BoxShadowDto>? boxShadow})
const

Properties

boxShadow List<BoxShadowDto>?
final
color ColorDto?
final
gradient GradientDto<Gradient>?
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
no setterinherited

Methods

getDiff(EqualityMixin other) Map<String, String>
inherited
merge(covariant DecorationDto<Decoration>? other) DecorationDto<Decoration>
Merges this object with other, returning a new object of type T.
override
mergeDecoration(covariant DecorationDto<Decoration>? other) DecorationDto<Decoration>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(MixData mix) → Value
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited