OnDirectionalityVariant class
A variant of ContextVariant based on a TextDirection value.
This class determines whether the current TextDirection within the given BuildContext matches the specified direction.
- Inheritance
-
- Object
- IVariant
- ContextVariant
- MediaQueryContextVariant
- OnDirectionalityVariant
Constructors
- OnDirectionalityVariant(TextDirection direction)
-
Creates a new OnDirectionalityVariant with the given
direction.const
Properties
- direction → TextDirection
-
The TextDirection associated with this variant.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mergeKey → Object
-
This key determines how variants should be merged.
For the most part, it's basically the runtimeType.
However, for some context variants and multivariants, it is different
as they can have different merge rules.
no setteroverride
- priority → VariantPriority
-
This is the priority at which the variants are applied.
In the case of some context variants that are due to
widget interactivity, they should be applied
at a higher priority than media query variants, for example.
finalinherited
-
props
→ List<
Object?> -
The properties used for equality comparison.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
no setterinherited
Methods
-
call(
[Attribute? p1, Attribute? p2, Attribute? p3, Attribute? p4, Attribute? p5, Attribute? p6, Attribute? p7, Attribute? p8, Attribute? p9, Attribute? p10, Attribute? p11, Attribute? p12, Attribute? p13, Attribute? p14, Attribute? p15, Attribute? p16, Attribute? p17, Attribute? p18, Attribute? p19, Attribute? p20]) → VariantAttribute< IVariant> -
inherited
-
getDiff(
EqualityMixin other) → Map< String, String> -
inherited
-
matches(
Iterable< IVariant> matchVariants) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when(
BuildContext context) → bool -
Determines whether the current TextDirection matches the specified direction.
override
Operators
-
operator &(
covariant IVariant variant) → MultiVariant -
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator |(
covariant IVariant variant) → MultiVariant -
inherited