unpressDelay property
The duration to wait after the press is released before the state of pressed is removed
Implementation
final Duration unpressDelay;
The duration to wait after the press is released before the state of pressed is removed
final Duration unpressDelay;